@@ -179,7 +179,7 @@ def main(omni_CLI=False):
             print('GUI ERROR: %s'%GUI_ERROR)
             if GUI_IMPORT:
                 print('GUI FAILED: GUI dependencies may not be installed, to install, run')
-                print('     pip install cellpose[gui]')
+                print('     pip install cellpose-omni[gui]')
         else:
             gui.run()
 
